# nodebot-server [![NPM version](https://img.shields.io/npm/v/nodebot-server.svg?style=flat)](https://www.npmjs.com/package/nodebot-server) [![NPM monthly downloads](https://img.shields.io/npm/dm/nodebot-server.svg?style=flat)](https://npmjs.org/package/nodebot-server)  [![NPM total downloads](https://img.shields.io/npm/dt/nodebot-server.svg?style=flat)](https://npmjs.org/package/nodebot-server)

> Simple socket.io server for controlling a nodebot.

## Install

Install with [npm](https://www.npmjs.com/):

```sh
$ npm install --save nodebot-server
```

## Usage

```js
var server = require('nodebot-server');
```

## API

### [.server](index.js#L35)

Start a web server hosting the index page and a websocket server to listen for commands to send to listening nodebots.

**Params**

* `options` **{Object}**: Options to control how the server is configured.
* `options.cwd` **{String}**: Directory where any static files to be served are found. Defaults to `process.cwd()`.
* `options.index` **{String}**: Relative path from `options.cwd` to the html file to serve when the root route is accessed. Defaults to `index.html`.
* `options.port` **{Number}**: Port for the web server to listen on. Defaults to 3000.
* `cb` **{Function}**: Callback function that is passed an `err` if an Error occurs, or an `app` when successful. See [app](#app).

**Example**

```js
var options = { cwd: __dirname, index: 'index.html' };
server(options, function(err, app) {
  if (err) {
    console.error(err);
    process.exit(1);
    return;
  }
  console.log('Nodebot server started.');

   // listen for commands
   app.on('cmd', function(cmd) {
     console.log(`Received command: ${cmd}`);
   });
});
```

### [app](index.js#L56)

Application instance that is used to listen for events to know when to send commands to your nodebots.

**Example**

```js
app.on('cmd', function(cmd) {
  console.log(cmd);
  //=> 'forward'
});
```

## Nodebot remote control

Use [nodebot remote control](https://github.com/jonschlinkert/nodebot-remote-control) to quickly get started with a UI for sending commands to the nodebot server.

[![nodebot remote control preview](https://raw.githubusercontent.com/jonschlinkert/nodebot-remote-control/master/src/nodebot-remote-control.jpg)](https://github.com/jonschlinkert/nodebot-remote-control)

Use the following steps to setup the [nodebot remote control](https://github.com/jonschlinkert/nodebot-remote-control):

* Clone [nodebot-remote-control](https://github.com/jonschlinkert/nodebot-remote-control) into a vendor folder in your nodebot project:

```sh
$ git clone https://github.com/jonschlinkert/nodebot-remote-control.git vendor/nodebot-remote-control
```

* Copy the files from `dist` into a folder in your nodebot project (we'll use `public`)

```sh
$ cp -R ./vendor/nodebot-remote-control/dist/ ./public
```

* Configure and start the [nodebot-server](https://github.com/doowb/nodebot-server) after connecting to your nodebot:

```js
var path = require('path');
var server = require('nodebot-server');
var options = {
  cwd: path.join(process.cwd(), 'public')
};

server(options, function(err, app) {
  if (err) {
    console.error(err);
    process.exit(1);
    return;
  }
  app.on('cmd', function(cmd) {
    // call function coorisponding to the command received
    nodebot[cmd]();
  });
});
```

## About

### Contributing

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](../../issues/new).

Please read the [contributing guide](contributing.md) for avice on opening issues, pull requests, and coding standards.

### Building docs

_(This document was generated by [verb-generate-readme](https://github.com/verbose/verb-generate-readme) (a [verb](https://github.com/verbose/verb) generator), please don't edit the readme directly. Any changes to the readme must be made in [.verb.md](.verb.md).)_

To generate the readme and API documentation with [verb](https://github.com/verbose/verb):

```sh
$ npm install -g verb verb-generate-readme && verb
```

### Running tests

Install dev dependencies:

```sh
$ npm install -d && npm test
```

### Author

**Brian Woodward**

* [github/doowb](https://github.com/doowb)
* [twitter/doowb](http://twitter.com/doowb)

### License

Copyright © 2017, [Brian Woodward](https://github.com/doowb).
Released under the [MIT license](LICENSE).

***

_This file was generated by [verb-generate-readme](https://github.com/verbose/verb-generate-readme), v0.2.3, on January 11, 2017._